package controllers

import (
	"encoding/json"
	"hongze/hz_eta_api/models"
	"hongze/hz_eta_api/utils"
	"html"
	"strings"
	"time"
)

// BusinessConfController 商家配置
type BusinessConfController struct {
	BaseAuthController
}

// Save
// @Title 保存配置
// @Description 保存配置
// @Param	request	body models.BusinessConfSaveReq true "type json string"
// @Success 200 Ret=200 操作成功
// @router /save [post]
func (this *BusinessConfController) Save() {
	br := new(models.BaseResponse).Init()
	defer func() {
		if br.ErrMsg == "" {
			br.IsSendEmail = false
		}
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}

	// 参数校验
	var req models.BusinessConfSaveReq
	if e := json.Unmarshal(this.Ctx.Input.RequestBody, &req); e != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + e.Error()
		return
	}
	req.Disclaimer = strings.TrimSpace(req.Disclaimer)
	if req.Disclaimer == "" {
		br.Msg = "请输入免责声明"
		return
	}
	req.CompanyName = strings.TrimSpace(req.CompanyName)
	if req.CompanyName == "" {
		br.Msg = "请输入公司名称"
		return
	}
	if len(req.CnPptCoverImgs) == 0 {
		br.Msg = "请上传中文PPT封面图"
		return
	}
	if len(req.CnPptCoverImgs) > 3 {
		br.Msg = "封面图最多上传3张"
		return
	}
	if req.CnPptBackgroundImg == "" {
		br.Msg = "请上传中文PPT背景图"
		return
	}
	if req.CnPptBackgroundImg == "" {
		br.Msg = "请上传中文PPT封底图"
		return
	}
	if len(req.EnPptCoverImgs) == 0 {
		br.Msg = "请上传英文PPT封面图"
		return
	}
	if len(req.EnPptCoverImgs) > 3 {
		br.Msg = "封面图最多上传3张"
		return
	}
	if req.EnPptBackgroundImg == "" {
		br.Msg = "请上传英文PPT背景图"
		return
	}
	if req.EnPptBottomImg == "" {
		br.Msg = "请上传英文PPT封底图"
		return
	}
	if req.UseXf == 1 {
		req.XfAppid = strings.TrimSpace(req.XfAppid)
		if req.XfAppid == "" {
			br.Msg = "请输入科大讯飞APPID"
			return
		}
		req.XfApiKey = strings.TrimSpace(req.XfApiKey)
		if req.XfApiKey == "" {
			br.Msg = "请输入科大讯飞APIKey"
			return
		}
		req.XfApiSecret = strings.TrimSpace(req.XfApiSecret)
		if req.XfApiSecret == "" {
			br.Msg = "请输入科大讯飞APISecret"
			return
		}
		req.XfVcn = strings.TrimSpace(req.XfVcn)
		if req.XfVcn == "" {
			br.Msg = "请输入科大讯飞Vcn"
			return
		}
	}

	item, e := models.GetBusinessConf()
	if e != nil && e.Error() != utils.ErrNoRow() {
		br.Msg = "保存失败"
		br.ErrMsg = "获取商家配置失败, Err: " + e.Error()
		return
	}

	isUpdate := false
	if item != nil {
		isUpdate = true
	} else {
		item = new(models.BusinessConf)
	}
	item.CompanyName = req.CompanyName
	item.CompanyWatermark = req.CompanyWatermark
	item.WatermarkChart = req.WatermarkChart
	item.CnPptCoverImgs = strings.Join(req.CnPptCoverImgs, ",")
	item.CnPptBackgroundImg = req.CnPptBackgroundImg
	item.CnPptBottomImg = req.CnPptBottomImg
	item.Disclaimer = html.EscapeString(req.Disclaimer)
	item.EnPptCoverImgs = strings.Join(req.EnPptCoverImgs, ",")
	item.EnPptBackgroundImg = req.EnPptBackgroundImg
	item.EnPptBottomImg = req.EnPptBottomImg
	item.UseXf = req.UseXf
	item.XfAppid = req.XfAppid
	item.XfApiKey = req.XfApiKey
	item.XfApiSecret = req.XfApiSecret
	item.XfVcn = req.XfVcn

	if isUpdate {
		cols := []string{
			"CompanyName", "CompanyWatermark", "WatermarkChart", "CnPptCoverImgs", "CnPptBackgroundImg", "CnPptBottomImg", "Disclaimer",
			"EnPptCoverImgs", "EnPptBackgroundImg", "EnPptBottomImg", "UseXf", "XfAppid", "XfApiKey", "XfApiSecret", "XfVcn",
		}
		if e = item.Update(cols); e != nil {
			br.Msg = "保存失败"
			br.ErrMsg = "更新商家配置失败, Err: " + e.Error()
			return
		}
	} else {
		if e = item.Create(); e != nil {
			br.Msg = "保存失败"
			br.ErrMsg = "新增商家配置失败, Err: " + e.Error()
			return
		}
	}

	// 操作日志
	go func() {
		b, e := json.Marshal(req)
		if e != nil {
			return
		}
		recordOb := new(models.BusinessConfOperationRecord)
		recordOb.SysUserId = sysUser.AdminId
		recordOb.SysRealName = sysUser.RealName
		recordOb.Content = string(b)
		recordOb.CreateTime = time.Now().Local()
		_ = recordOb.Create()
	}()

	br.Ret = 200
	br.Success = true
	br.Msg = "操作成功"
}

// Fetch
// @Title 获取配置
// @Description 获取配置
// @Success 200 Ret=200 获取成功
// @router /fetch [get]
func (this *BusinessConfController) Fetch() {
	br := new(models.BaseResponse).Init()
	defer func() {
		if br.ErrMsg == "" {
			br.IsSendEmail = false
		}
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}

	item, e := models.GetBusinessConf()
	if e != nil && e.Error() != utils.ErrNoRow() {
		br.Msg = "保存失败"
		br.ErrMsg = "获取商家配置失败, Err: " + e.Error()
		return
	}
	res := new(models.BusinessConfItem)
	res.CnPptCoverImgs = make([]string, 0)
	res.EnPptCoverImgs = make([]string, 0)
	if item != nil {
		res.CompanyName = item.CompanyName
		res.CompanyWatermark = item.CompanyWatermark
		res.WatermarkChart = item.WatermarkChart
		res.CnPptCoverImgs = strings.Split(item.CnPptCoverImgs, ",")
		res.CnPptBackgroundImg = item.CnPptBackgroundImg
		res.CnPptBottomImg = item.CnPptBottomImg
		res.Disclaimer = html.UnescapeString(item.Disclaimer)
		res.EnPptCoverImgs = strings.Split(item.EnPptCoverImgs, ",")
		res.EnPptBackgroundImg = item.EnPptBackgroundImg
		res.EnPptBottomImg = item.EnPptBottomImg
		res.UseXf = item.UseXf
		res.XfAppid = item.XfAppid
		res.XfApiKey = item.XfApiKey
		res.XfApiSecret = item.XfApiSecret
		res.XfVcn = item.XfVcn
	}

	br.Data = res
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
}
